@@ -20,7 +20,14 @@ Args:
 
 __tail_doc__ = """  features_pick: specific `layer names` or `pyramid feature indexes` from backbone model.
         Default `[-3, -2, -1]` means using the last 3 pyramid feature output from backbone.
-  use_anchor_free_mode: boolean value if use anchor free mode. num_anchors = 1 if use_anchor_free_mode else 3. Default False.
+  use_anchor_free_mode: boolean value if use anchor free mode. Default False.
+  use_yolor_anchors_mode: boolean value if use yolor anchors mode. Default True.
+      Currently 3 types anchors supported:
+      - efficientdet anchors default settings: use_object_scores=False, num_anchors=9, anchor_scale=4,
+          aspect_ratios=[1, 2, 0.5], num_scales=3, grid_zero_start=False.
+      - anchor_free_mode default settings: use_object_scores=True, num_anchors=1, anchor_scale=1,
+          aspect_ratios=[1], num_scales=1, grid_zero_start=True.
+      - yolor_anchors_mode default settings: use_object_scores=True, num_anchors=3.
   num_anchors: number of anchors for a single grid point, should be same with dataset used value.
       Default "auto" means 1 if use_anchor_free_mode else 3
   use_object_scores: bollean value if model header output includes `object_scores`. Default True.
